CreateFeatureCommand class

Command to create a new feature module with Clean Architecture layers.

Generates:

  • Presentation layer (BLoC, Pages, Widgets)
  • Domain layer (Entities, Use Cases, Repository Interface)
  • Data layer (Models, Data Sources, Repository Implementation)
  • Automatic routing setup
  • Dependency registration

Constructors

CreateFeatureCommand(String featureName)
Creates a new CreateFeatureCommand with the given featureName.

Properties

featureName String
The name of the feature to create.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited