CreatePageCommand class

Constructors

CreatePageCommand(String featureName, String pageName, {bool withBloc = true, bool withData = false})

Properties

featureName String
final
hashCode int
The hash code for this object.
no setterinherited
pageName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
withBloc bool
final
withData bool
final

Methods

execute() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited