BlocGenerator class

Generator for creating BLoC (Business Logic Component) files.

Generates bloc, event, and state files following the flutter_bloc pattern.

Constructors

BlocGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(String snakeName, String pascalName, String camelName, {bool withData = false}) Map<String, String>
Generates BLoC files for a feature.