DataSourceGenerator class

Generator for creating remote data source classes.

Generates data source classes that handle API communication using DioClient from the core package.

Constructors

DataSourceGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(String snakeName, String pascalName) String
Generates a remote data source class for the given feature.