EntityGenerator class

Generator for creating domain entity classes.

Generates entity classes that represent the core domain models using Equatable for value equality.

Constructors

EntityGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(String snakeName, String pascalName) String
Generates a domain entity class for the given feature.