ModelGenerator class

Generator for creating data model classes.

Generates model classes that extend domain entities and add JSON serialization capabilities for API communication.

Constructors

ModelGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(String snakeName, String pascalName) String
Generates a data model class for the given feature.