PageGenerator class

Generator for creating Flutter page widgets.

Generates page widgets with optional BLoC integration and data layer support.

Constructors

PageGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(String snakeName, String pascalName, String camelName, {bool withData = false}) String
Generates a Flutter page widget for the given feature.