RepositoryGenerator class

Generator for creating repository interface classes.

Generates abstract repository classes that define the contract for data operations following Clean Architecture principles.

Constructors

RepositoryGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(String snakeName, String pascalName) String
Generates a repository interface for the given feature.