UseCaseGenerator class

Generator for creating use case classes.

Generates use case classes that encapsulate business logic following the Single Responsibility Principle.

Constructors

UseCaseGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(String snakeName, String pascalName, String camelName) String
Generates use case classes for the given feature.