info static method
Prints an info message in blue with an info symbol.
Implementation
static void info(String message) {
print('$_blue ℹ$_reset $message');
}
Prints an info message in blue with an info symbol.
static void info(String message) {
print('$_blue ℹ$_reset $message');
}