step static method
Prints a step message in cyan with an arrow symbol.
Implementation
static void step(String message) {
print('$_cyan▸$_reset $message');
}
Prints a step message in cyan with an arrow symbol.
static void step(String message) {
print('$_cyan▸$_reset $message');
}