success static method
Prints a success message in green with a checkmark.
Implementation
static void success(String message) {
print('$_greenâś“$_reset $message');
}
Prints a success message in green with a checkmark.
static void success(String message) {
print('$_greenâś“$_reset $message');
}