warning static method
Prints a warning message in yellow with a warning symbol.
Implementation
static void warning(String message) {
print('$_yellow⚠$_reset $message');
}
Prints a warning message in yellow with a warning symbol.
static void warning(String message) {
print('$_yellow⚠$_reset $message');
}