StringUtils class

Utility class for string case conversions.

Provides methods to convert strings between different naming conventions commonly used in code generation.

Constructors

StringUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toCamelCase(String input) String
Converts input to camelCase.
toPascalCase(String input) String
Converts input to PascalCase.
toSnakeCase(String input) String
Converts input to snake_case.
toTitleCase(String input) String
Converts input to Title Case.